pub struct DataAggregator {
pub chunks: Vec<Chunk>,
pub pending_file_info: Vec<(MDBFileInfo, Vec<usize>, u64)>,
pub file_boundaries: Vec<usize>,
/* private fields */
}Fields
chunks: Vec<Chunk>pending_file_info: Vec<(MDBFileInfo, Vec<usize>, u64)>file_boundaries: Vec<usize>Implementations
Sourceimpl DataAggregator
impl DataAggregator
pub fn is_empty(&self) -> bool
pub fn num_chunks(&self) -> usize
pub fn num_bytes(&self) -> usize
Sourcepub fn finalize(self) -> (RawXorbData, Vec<(u64, MDBFileInfo, u64)>)
pub fn finalize(self) -> (RawXorbData, Vec<(u64, MDBFileInfo, u64)>)
Finalize the result, returning the xorb data, and a Vec of (file_id, file_info, n_bytes_in_xorb); i.e. the file info that’s included in this along with the number of bytes in each file that is part of this xorb.
pub fn merge_in(&mut self, other: DataAggregator)