pub struct DeduplicationMetrics {Show 13 fields
pub total_bytes: u64,
pub deduped_bytes: u64,
pub new_bytes: u64,
pub deduped_bytes_by_global_dedup: u64,
pub defrag_prevented_dedup_bytes: u64,
pub total_chunks: u64,
pub deduped_chunks: u64,
pub new_chunks: u64,
pub deduped_chunks_by_global_dedup: u64,
pub defrag_prevented_dedup_chunks: u64,
pub xorb_bytes_uploaded: u64,
pub shard_bytes_uploaded: u64,
pub total_bytes_uploaded: u64,
}Fields
total_bytes: u64deduped_bytes: u64new_bytes: u64deduped_bytes_by_global_dedup: u64defrag_prevented_dedup_bytes: u64total_chunks: u64deduped_chunks: u64new_chunks: u64deduped_chunks_by_global_dedup: u64defrag_prevented_dedup_chunks: u64xorb_bytes_uploaded: u64shard_bytes_uploaded: u64total_bytes_uploaded: u64Implementations
Sourceimpl DeduplicationMetrics
Implement + for the metrics above, so they can be added
and updated after each call to process_chunks.
impl DeduplicationMetrics
Implement + for the metrics above, so they can be added and updated after each call to process_chunks.