pub struct FileTerm {
pub byte_range: FileRange,
pub xorb_chunk_range: ChunkRange,
pub xorb_block_start_index: usize,
pub offset_into_first_range: u64,
pub xorb_block: Arc<XorbBlock>,
pub url_info: Arc<TermBlockRetrievalURLs>,
}Expand description
A single term in a file reconstruction, representing a contiguous byte range in the output file that maps to a chunk range within a xorb block.
Fields
byte_range: FileRangexorb_chunk_range: ChunkRangexorb_block_start_index: usizeoffset_into_first_range: u64xorb_block: Arc<XorbBlock>url_info: Arc<TermBlockRetrievalURLs>Implementations
Sourceimpl FileTerm
impl FileTerm
pub fn extract_bytes(&self, xorb_block_data: &XorbBlockData) -> Bytes
Sourcepub async fn get_data_task(
&self,
client: Arc<dyn Client>,
progress_updater: Option<Arc<ItemProgressUpdater>>,
chunk_cache: Option<Arc<dyn ChunkCache>>,
) -> Result<Pin<Box<dyn Future<Output = Result<Bytes>> + Send + 'static>>>
pub async fn get_data_task( &self, client: Arc<dyn Client>, progress_updater: Option<Arc<ItemProgressUpdater>>, chunk_cache: Option<Arc<dyn ChunkCache>>, ) -> Result<Pin<Box<dyn Future<Output = Result<Bytes>> + Send + 'static>>>
Get a future that will retrieve and extract the data bytes for this file term.
If the xorb data is already cached, returns a future that immediately resolves (no progress report, since the block was already reported by the term that triggered the download). Otherwise, spawns a task that calls retrieve_data, which uses single-flight to ensure only one download per xorb block (other callers wait without acquiring CAS permits).