pub struct SequentialWriter { /* private fields */ }Expand description
Writes data sequentially to an output stream from async data futures. Spawns async tasks to resolve futures and a background thread to perform blocking writes, allowing out-of-order future resolution with in-order writes.