Module processing

Module processing 

Re-exports

pub use crate::file_reconstruction::DownloadStream;
pub use crate::file_reconstruction::UnorderedDownloadStream;

Modules

configurations
data_client
migration_tool
test_utils

Structs

FileDownloadSession
Manages the downloading of files from CAS storage.
FileUploadSession
Manages the translation of files between the MerkleDB / pointer file format and the materialized version.
RawXorbData
This struct is the data needed to cut a
SingleFileCleaner
A class that encapsulates the clean and data task around a single file.
XetFileInfo
A struct that wraps a the Xet file information.

Enums

Sha256Policy
Controls how SHA-256 is handled during file cleaning.