pub struct RawXorbData {
pub data: Vec<Bytes>,
pub xorb_info: MDBXorbInfo,
pub file_boundaries: Vec<usize>,
}Expand description
This struct is the data needed to cut a
Fields
data: Vec<Bytes>The data for the xorb info.
xorb_info: MDBXorbInfoThe cas info associated with the current xorb.
file_boundaries: Vec<usize>The indices where a new file starts, to be used for the compression heuristic.
Implementations
Sourceimpl RawXorbData
impl RawXorbData