XetFileInfo

Struct XetFileInfo 

pub struct XetFileInfo {
    pub hash: String,
    pub file_size: Option<u64>,
    pub sha256: Option<String>,
}
A struct that wraps a the Xet file information.

Fields

hash: String

The Merkle hash of the file

file_size: Option<u64>

The size of the file, if known.

sha256: Option<String>

The SHA-256 hash of the file, if available.

Implementations

Source

impl XetFileInfo

pub fn new(hash: String, file_size: u64) -> Self

Creates a new XetFileInfo instance with a known size.

Arguments
  • hash - The Xet hash of the file. This is a Merkle hash string.
  • file_size - The size of the file.
pub fn new_with_sha256(hash: String, file_size: u64, sha256: String) -> Self

Creates a new XetFileInfo instance with a SHA-256 hash and known size.

pub fn new_hash_only(hash: String) -> Self

Creates a new XetFileInfo with only a hash and no known size.

pub fn hash(&self) -> &str

Returns the Merkle hash of the file.

pub fn merkle_hash(&self) -> Result<MerkleHash, DataHashHexParseError>

Returns the parsed merkle hash of the file.

pub fn file_size(&self) -> Option<u64>

Returns the size of the file, if known.

pub fn sha256(&self) -> Option<&str>

Returns the SHA-256 hash of the file, if available.

pub fn as_pointer_file(&self) -> Result<String, Error>