Module test_utils

Module test_utils 

Structs

HydrateDehydrateTest
TestEnvironment
Provides a test environment with a config suitable for FileUploadSession / FileDownloadSession.

Enums

HydrationMode
Describes how hydration (download/smudge) should be performed during a test.

Functions

create_random_file
Creates or overwrites a single file in dir with size bytes of random data. Panics on any I/O error. Returns the total number of bytes written (=size).
create_random_files
Creates a collection of random files, each with a deterministic seed. the total number of bytes written for all files combined.
create_random_multipart_file
Creates or overwrites a single file in dir with consecutive segments determined by the list of [(size, seed)]. Panics on any I/O error. Returns the total number of bytes written (=size).
verify_directories_match
Panics if dir1 and dir2 differ in terms of files or file contents. Uses unwrap() everywhere; intended for test-only use.