create_random_files

Function create_random_files 

pub fn create_random_files(
    dir: impl AsRef<Path>,
    files: &[(impl AsRef<str>, usize)],
    seed: u64,
) -> usize
Creates a collection of random files, each with a deterministic seed. the total number of bytes written for all files combined.