create_random_multipart_file

Function create_random_multipart_file 

pub fn create_random_multipart_file(
    path: impl AsRef<Path>,
    segments: &[(usize, u64)],
) -> usize
Creates or overwrites a single file in dir with consecutive segments determined by the list of [(size, seed)]. Panics on any I/O error. Returns the total number of bytes written (=size).