Module upload_tracking

Module upload_tracking 

Structs

CompletionTracker
FileXorbDependency

Type Aliases

CompletionTrackerFileId
A type with with to track a File ID; reporting is done by Arc, but this ensures the bookkeeping is correct across duplicates and speeds up the updates.