pub struct FileDeduper<DataInterfaceType: DeduplicationDataInterface> { /* private fields */ }Implementations
Sourceimpl<DataInterfaceType: DeduplicationDataInterface> FileDeduper<DataInterfaceType>
impl<DataInterfaceType: DeduplicationDataInterface> FileDeduper<DataInterfaceType>
pub fn new(data_manager: DataInterfaceType, file_id: u64) -> Self
pub async fn process_chunks( &mut self, chunks: &[Chunk], ) -> Result<DeduplicationMetrics, DataInterfaceType::ErrorType>
Sourcepub fn finalize(
self,
metadata_ext: Option<FileMetadataExt>,
) -> (MerkleHash, DataAggregator, DeduplicationMetrics)
pub fn finalize( self, metadata_ext: Option<FileMetadataExt>, ) -> (MerkleHash, DataAggregator, DeduplicationMetrics)
Finalize the internal state, converting remaining data to a DataAggregator object that contains the file info and remaining data. Also returns the aggregated deduplication metrics and the list of xorb hashes that were registered as part of this run.
Returns (file hash, data aggregation, deduplication metrics)