pub struct ReconstructionTermManager { /* private fields */ }Expand description
Manages the iteration over file terms during reconstruction, with adaptive prefetching. Prefetches reconstruction blocks ahead of consumption based on observed completion rates to minimize download latency while controlling memory usage.
Implementations
Sourceimpl ReconstructionTermManager
impl ReconstructionTermManager
pub async fn new( config: Arc<ReconstructionConfig>, client: Arc<dyn Client>, file_hash: MerkleHash, file_byte_range: FileRange, progress_updater: Option<Arc<ItemProgressUpdater>>, ) -> Result<Self>