Module processing

Module processing 

Re-exports

pub use range_upload::DirtyInput;
pub use range_upload::upload_ranges;
pub use crate::file_reconstruction::DownloadStream;
pub use crate::file_reconstruction::UnorderedDownloadStream;

Modules

configurations
data_client
migration_tool
range_upload
test_utils

Structs

CacheConfig
FileDownloadSession
Manages the downloading of files from CAS storage.
FileUploadSession
Manages the translation of files between the MerkleDB / pointer file format and the materialized version.
RawXorbData
This struct is the data needed to cut a
SingleFileCleaner
A class that encapsulates the clean and data task around a single file.
XetFileInfo
A struct that wraps a the Xet file information.

Enums

Sha256Policy
Controls how SHA-256 is handled during file cleaning.

Traits

CasClient
A Client to the Shard service. The shard service provides for
ChunkCache
ChunkCache is a trait for storing and fetching Xorb ranges. implementors are expected to return bytes for a key and a given chunk range (no compression or further deserialization should be required) Range inputs use chunk indices in an end exclusive way i.e. [start, end)

Functions

create_remote_client
get_cache
get_cache attempts to return a cache given the provided config parameter

Type Aliases

ChunkHashList
List of (chunk_hash, chunk_uncompressed_size) pairs for a file or xorb range.