Re-exports
pub use range_upload::DirtyInput;pub use range_upload::upload_ranges;pub use crate::file_reconstruction::DownloadStream;pub use crate::file_reconstruction::UnorderedDownloadStream;
Modules
Structs
- Cache
Config - File
Download Session - Manages the downloading of files from CAS storage.
- File
Upload Session - Manages the translation of files between the MerkleDB / pointer file format and the materialized version.
- RawXorb
Data - This struct is the data needed to cut a
- Single
File Cleaner - A class that encapsulates the clean and data task around a single file.
- XetFile
Info - A struct that wraps a the Xet file information.
Enums
- Sha256
Policy - Controls how SHA-256 is handled during file cleaning.
Traits
- CasClient
- A Client to the Shard service. The shard service provides for
- Chunk
Cache - ChunkCache is a trait for storing and fetching Xorb ranges. implementors are expected to return bytes for a key and a given chunk range (no compression or further deserialization should be required) Range inputs use chunk indices in an end exclusive way i.e. [start, end)
Functions
- create_
remote_ client - get_
cache - get_cache attempts to return a cache given the provided config parameter
Type Aliases
- Chunk
Hash List - List of (chunk_hash, chunk_uncompressed_size) pairs for a file or xorb range.