Re-exports
pub use crate::file_reconstruction::DownloadStream;pub use crate::file_reconstruction::UnorderedDownloadStream;
Modules
Structs
- File
Download Session - Manages the downloading of files from CAS storage.
- File
Upload Session - Manages the translation of files between the MerkleDB / pointer file format and the materialized version.
- RawXorb
Data - This struct is the data needed to cut a
- Single
File Cleaner - A class that encapsulates the clean and data task around a single file.
- XetFile
Info - A struct that wraps a the Xet file information.
Enums
- Sha256
Policy - Controls how SHA-256 is handled during file cleaning.