pub struct SingleFileCleaner { /* private fields */ }Expand description
A class that encapsulates the clean and data task around a single file.
Implementations
Sourceimpl SingleFileCleaner
impl SingleFileCleaner
pub async fn add_data(&mut self, data: &[u8]) -> Result<()>
pub async fn add_data_from_bytes(&mut self, data: Bytes) -> Result<()>
Sourcepub async fn checkpoint(&mut self) -> Result<()>
pub async fn checkpoint(&mut self) -> Result<()>
Ensures all current background work is completed.
Sourcepub async fn finish(self) -> Result<(XetFileInfo, DeduplicationMetrics)>
pub async fn finish(self) -> Result<(XetFileInfo, DeduplicationMetrics)>
Return the representation of the file after clean as a pointer file instance.