Module upload_tracking
xet_
data
1.5.1
Module upload_
tracking
Module Items
Structs
Type Aliases
In xet_
data::
progress_
tracking
xet_data
::
progress_tracking
Module
upload_
tracking
Structs

Completion
Tracker
File
Xorb
Dependency
Type Aliases

Completion
Tracker
File
Id
A type with with to track a File ID; reporting is done by Arc
, but this ensures the bookkeeping is correct across duplicates and speeds up the updates.